# -*- coding: utf-8 -*-

import bpy
from bpy.props import (
    BoolProperty,
    IntProperty,
    FloatVectorProperty,
)


# パネル情報クラス
class PgToys_Property(bpy.types.PropertyGroup):
    # 頂点番号表示
    show_vertex_index: BoolProperty(default=False, name="Show Vertex Index")
    # 辺番号表示
    show_edge_index: BoolProperty(default=False, name="Show Edge Index")
    # 面番号表示
    show_face_index: BoolProperty(default=False, name="Show Face Index")
    # 辺の長さ表示
    show_edge_length: BoolProperty(default=False, name="Show Edge Length")
    # 角度表示
    show_angle: BoolProperty(default=False, name="Show Edge Angle")
    # リンク先もたどるか
    show_linked: BoolProperty(default=False, name="Show Linked")
    # UV座標を表示するか
    show_uv_coord: BoolProperty(default=False, name="Show UVs")
    # 文字サイズ
    font_size: IntProperty(default=16, min=10, max=30)
    # 文字色
    font_color: FloatVectorProperty(default=(1.0, 1.0, 1.0), min=0.0, max=1.0, subtype="COLOR")
    # 表示上限
    show_limit: IntProperty(default=5000, min=100)


# パネルクラス(情報)
class PgToys_PT_PgToysInfos(bpy.types.Panel):
    bl_label = "Model Infos"
    bl_idname = "VIEW3D_PT_pg_toysInfos"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_category = "PgToys"

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        PgToys = context.scene.PgToysProperty

        box = layout.box()
        column = box.column(align=False)

        column.label(text="Show Index:")
        row = column.row(align=False)
        # 頂点番号表示(チェックボックス)
        row.prop(PgToys, "show_vertex_index", text="Vertex")
        # 辺番号表示(チェックボックス)
        row.prop(PgToys, "show_edge_index", text="Edge")
        # 面番号表示(チェックボックス)
        row.prop(PgToys, "show_face_index", text="Face")

        column.label(text="Show Edge & Angle Infos:")
        row = column.row(align=False)
        # 辺の長さ表示(チェックボックス)
        row.prop(PgToys, "show_edge_length", text="Length")
        # 辺の角度表示(チェックボックス)
        row.prop(PgToys, "show_angle", text="Angle")
        # リンク先もたどるか(チェックボックス)
        row.prop(PgToys, "show_linked", text="Linked")

        column.label(text="Show UV:")
        row = column.row(align=False)
        # UV座標の表示(チェックボックス)
        row.prop(PgToys, "show_uv_coord", text="UV Coord")

        # ラベルと値の表示を分離
        column.use_property_split = True
        # 分離時に出るデコレータ？領域を表示するか
        column.use_property_decorate = False

        # 文字サイズ
        column.prop(PgToys, "font_size", text="Size")
        # 文字色
        column.prop(PgToys, "font_color", text="Color")
        # 表示上限
        column.prop(PgToys, "show_limit", text="Show Limit")


# パネルクラス(Tools)
class PgToys_PT_PgToysTools(bpy.types.Panel):
    bl_label = "Tools"
    bl_idname = "VIEW3D_PT_pg_toysTools"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_category = "PgToys"

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        PgToys = context.scene.PgToysProperty

        box = layout.box()
        column = box.column(align=False)

        # ポリゴン情報(チェックボックス)
        column.prop(
            context.space_data.overlay,
            "show_stats",
            text="Show Object Infos",
            icon="INFO",
        )
        # 頂点法線表示(チェックボックス)
        column.prop(
            context.space_data.overlay,
            "show_vertex_normals",
            text="Show Vertex Normals",
            icon="NORMALS_VERTEX",
        )
        # 面法線表示(チェックボックス)
        column.prop(
            context.space_data.overlay,
            "show_face_normals",
            text="Show Face Normals",
            icon="NORMALS_FACE",
        )
        # エッジ強調(キャビティ)
        column.prop(
            context.space_data.shading,
            "show_cavity",
            text="Show Cavity",
            icon="SNAP_VOLUME",
        )
        # 面の向き
        column.prop(
            context.space_data.overlay,
            "show_face_orientation",
            text="Face Orientation",
            icon="CONE",
        )
